@@ -252,6 +252,10 @@ class FileOutputPlugin(nose.plugins.Plugin):
         #assert exists(self.result_file), 'file not found!'
         self.result_properties = {}
 
+    def describeTest(self, test):
+        module_name, class_name, method_name = test.id().split('.')[-3:]
+        return method_name
+
     def begin(self):
         self.test_start_time = getattr(self.conf, 'test_start_time', None)
         if not self.test_start_time:
